@@ -41,6 +41,7 @@ pub enum Topics {
     TypeScript,
 }
 
+// #[cfg_attr(feature = "magic", twitter, github)]
 pub mod social {
     pub const Twitter: &str = "btwiuse";
     pub const GitHub: &str = "btwiuse";
@@ -63,6 +64,12 @@ pub mod how_to_install_archlinux;
 pub mod Español {}
 pub mod 日本語 {}
 
+#[cfg(feature = "arch")]
+pub struct Arch;
+
+#[cfg(feature = "arch")]
+impl TagArch for Arch {}
+
 #[cfg(feature = "arch")]
 pub use BTW::I::USE::ARCH::*;
 
@@ -76,8 +83,11 @@ impl<T: Empty> Any for T {}
 
 pub trait GitHub {}
 
+#[cfg(feature = "linux")]
+pub trait TagLinux {}
+
 #[cfg(feature = "arch")]
-pub trait Linux {}
+pub trait TagArch {}
 
 pub trait Windows {}
 
